@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 112 2011-12-29 01:37:20Z yablacky $
+# $Id: smscon_service.py 118 2011-12-29 15:53:33Z yablacky $
 ##############################################################
 
 # standard modules
@@ -1083,7 +1083,7 @@ def GetGPRSname():
     CurrentIMSI = smscon.GetPhoneCode('IMSI')
 
     for Network in NetworkList:
-        Type, IAP, Name, Imsi = (Network + ['NONE', 'NONE'])[0:4]
+        Type, IAP, Name, Imsi = (list(Network) + ['NONE', 'NONE', 'NONE', 'NONE'])[0:4]
         if Type == 'GPRS' and Imsi == CurrentIMSI:
             LOGGER.debug('original IAP=[%s]' % IAP)
             return Type, IAP.replace('@32@', ' '), Name
